import getAccessTokenDispatcher from "./getAccessToken";

// test data: 6697e96f70b84092deb6132b, 61381e32f27ab4fbed1ec26e
export async function authSubject(request, env, ctx) {
    const headers = request.headers;
    const studyId = headers.get('x-study-id');
    const subjectId = headers.get('x-subject-id');
    const prolificApiKey = env.PROLIFIC_API_KEY;

    if (!studyId || !subjectId || !subjectId.match(/^[a-zA-Z0-9]{1,32}$/))
        return false;

    try {
        const apiUrl = `https://api.prolific.com/api/v1/studies/${studyId}/submissions/`;
        const res = await fetch(apiUrl, {
            headers: { Authorization: `Token ${prolificApiKey}` }
        });
        let data = await res.json();
        return Array.from(data.results).some(p => p.participant_id === subjectId);

    } catch (e) { console.log(e); return false; }
}

export async function authDispatcher(request, env, ctx) {
    if (await authSubject(request, env, ctx)) {
        return await getAccessTokenDispatcher(request, env, ctx);
    } else return new Response(null, { status: 401, statusText: 'Unauthorized' });
}

export default authDispatcher;