export async function downloadDispatcher(request, env, ctx) {
    const url = new URL(request.url);
    const uri = url.pathname;

    const bucket = env.EXP_DATA;
    const adminSecret = env.ADMIN_SECRET;

    if (request.headers.get('x-access-token') !== adminSecret)
        return new Response(null, { status: 401, statusText: 'Unauthorized' });
    try {
        const key = uri.slice(10); // '/download/'.length
        const object = await bucket.get(key);
        if (object === null)
            return new Response(null, { status: 404, statusText: 'Not Found' });

        const { body, etag, httpMetadata, customMetadata } = object;
        return new Response(body, { headers: {
            etag: etag,
            'content-type': httpMetadata.contentType,
            'content-length': body.length,
            'x-metadata': JSON.stringify(customMetadata),
        }});

    } catch (e) { return new Response(null, { status: 400 }); }
}

export default downloadDispatcher;