/**
 * Welcome to Cloudflare Workers! This is your first worker.
 *
 * - Run `npm run dev` in your terminal to start a development server
 * - Open a browser tab at http://localhost:8787/ to see your worker in action
 * - Run `npm run deploy` to publish your worker
 *
 * Learn more at https://developers.cloudflare.com/workers/
 */
import getAccessTokenDispatcher from './getAccessToken.js';
import authDispatcher from './auth.js';
import listDispatcher from './list.js';
import downloadDispatcher from './download.js';
import putDispatcher from './put.js';

export default {
	async fetch(request, env, ctx) {
		const url = new URL(request.url);
    	const uri = url.pathname;
		if (url.hostname !== '127.0.0.1' && url.protocol === 'http:') {
			return new Response(null, { status: 301, headers: {
				Location: url.toString().replace(/^(http:)/, 'https:')
			}});
		}

		if (request.method === 'GET' && uri === '/getAccessToken') {
			return await getAccessTokenDispatcher(request, env, ctx);
		}

		if (request.method === 'GET' && uri === '/auth') {
			return await authDispatcher(request, env, ctx);
		}

		if (request.method === 'GET' && uri === '/list') {
			return await listDispatcher(request, env, ctx);	
		}

		if (request.method === 'GET' && uri.startsWith('/download/')) {
			return await downloadDispatcher(request, env, ctx);
		}
		
		if (request.method === 'PUT') {
			return await putDispatcher(request, env, ctx);
		}
		
		return new Response('', { status: 200 });
	},
};
