export async function listDispatcher(request, env, ctx) {
    const bucket = env.EXP_DATA;
    const adminSecret = env.ADMIN_SECRET;
    const badRequest = new Response(null, { status: 400 });
    
    if (request.headers.get('x-access-token') !== adminSecret)
        return new Response(null, { status: 401, statusText: 'Unauthorized' });
    try {
        const type = request.headers.get('x-list-type') || 'prefix';
        let pattern = request.headers.get('x-pattern') || '';
        
        let objects = [];
        let truncated = true;
        let cursor = "";
        switch (type) {
            case 'prefix':
                while (truncated) {
                    const res = await bucket.list({ prefix: pattern, cursor });
                    objects = objects.concat(res.objects);
                    truncated = res.truncated;
                    cursor = res.cursor;
                }
                break;
            case 'suffix':
                pattern += '$';
            case 'regex':
                while (truncated) {
                    const res = await bucket.list({ cursor: cursor });
                    objects = objects.concat(res.objects);
                    truncated = res.truncated;
                    cursor = res.cursor;
                }
                pattern = new RegExp(pattern);
                objects = objects.filter(obj => obj.key.match(pattern));
                break;
            default:
                return badRequest;
        }

        const res = JSON.stringify(objects, ['key', 'etag', 'size', 'uploaded']);
        return new Response(res, { status: 200 });
    } catch (e) {
        console.error(e);
        return badRequest;
    }
}

export default listDispatcher;