import { verifyAccessToken } from "./getAccessToken";

const allowedContentTypes = [
	'text/plain',
	'text/csv',
];

async function invalidPutRequest(request, env, ctx) {
    const headers = request.headers;
	const subid = headers.get('x-subject-id');
	const contentType = headers.get('content-type');
	
	return (subid === null)
		|| (!subid.match(/^[a-zA-Z0-9]{1,32}$/))
		|| (!await verifyAccessToken(request, env, ctx))
		|| (!allowedContentTypes.includes(contentType));
}

export async function putDispatcher(request, env, ctx) {
    const url = new URL(request.url);
    const uri = url.pathname;
    const headers = request.headers;
    
    const bucket = env.EXP_DATA;
    const keyPrefix = env.KEY_PREFIX;
    const timestamp = new Date().toISOString().replace(/:/g, '_');
    
    try {
        if (await invalidPutRequest(request, env, ctx))
            return new Response(null, { status: 401, statusText: 'Unauthorized' });
        
        const subid = headers.get('x-subject-id');
        const data = await request.text();
        const objectKey = `${subid}${uri}`;
        const customMetadata = JSON.parse(headers.get('x-metadata') || '{}');
        const httpMetadata = { contentType: headers.get('content-type') };
        const result = await bucket.put(
            keyPrefix + objectKey,
            data,
            { customMetadata, httpMetadata }
        );
        
        return new Response(JSON.stringify({
            timestamp,
            objectKey,
            etag: result.etag,
            message: 'Data saved successfully',
        }), { status: 200 });

    } catch (e) { console.log(e); return new Response(null, { status: 400 }); }
}

export default putDispatcher;